@@ -4,6 +4,7 @@ packages to different locations.
 
 """
 import os
+import shutil
 import stat
 
 rc_template = \
@@ -12,6 +13,10 @@ export PATH=%s:$PATH
 """
 
 
+class DirectoryException(Exception):
+    """ An exception to specify it's a directory """
+
+
 class Directory(object):
 
     root_dir = None  # path to the root directory
@@ -21,9 +26,9 @@ class Directory(object):
                        # preserved, and will not be modifiable
     rc_file = None  # file handler for rc file
 
-    def __init__(self, namespace, rewrite_rc=True):
+    def __init__(self, namespace, rewrite_rc=True, sprinter_root=os.path.join("~", ".sprinter")):
         """ takes in a namespace directory to initialize, defaults to .sprinter otherwise."""
-        self.root_dir = os.path.expanduser(os.path.join("~", ".sprinter", namespace))
+        self.root_dir = os.path.expanduser(os.path.join(sprinter_root, namespace))
         self.new = not os.path.exists(self.root_dir)
         self.manifest_path = os.path.join(self.root_dir, "manifest.cfg")
         self.rewrite_rc = rewrite_rc
@@ -33,9 +38,23 @@ class Directory(object):
             self.rc_file.close()
 
     def initialize(self):
-        self.__generate_dir(self.root_dir)
-        if self.rewrite_rc:
-            self.rc_path, self.rc_file = self.__get_rc_handle(self.root_dir)
+        """ Generate the root directory root if it doesn't already exist """
+        if not os.path.exists(self.root_dir):
+            os.makedirs(self.root_dir)
+        assert os.path.isdir(self.root_dir), "%s is not a directory! Please move or remove it." % self.root_dir
+        for d in ["bin", "lib"]:
+            target_path = os.path.join(self.root_dir, d)
+            if not os.path.exists(target_path):
+                os.makedirs(target_path)
+        if not os.path.exists(self.manifest_path):
+            open(self.manifest_path, "w+").close()
+        self.new = False
+
+    def remove(self):
+        """ Removes the sprinter directory, if it exists """
+        if self.rc_file:
+            self.rc_file.close()
+        shutil.rmtree(self.root_dir)
 
     def symlink_to_bin(self, name, path):
         """
@@ -57,7 +76,7 @@ class Directory(object):
 
     def lib_path(self):
         """ return the lib directory path """
-        return os.path.join(self.root_dir, "bin")
+        return os.path.join(self.root_dir, "lib")
 
     def install_directory(self, feature_name):
         """
@@ -70,21 +89,11 @@ class Directory(object):
         add content to the rc script.
         """
         if not self.rewrite_rc:
-            raise Exception("Error! Directory was not intialized w/ rewrite_rc.")
+            raise DirectoryException("Error! Directory was not intialized w/ rewrite_rc.")
+        if not self.rc_file:
+            self.rc_path, self.rc_file = self.__get_rc_handle(self.root_dir)
         self.rc_file.write(content + '\n')
 
-    def __generate_dir(self, root_dir):
-        """ Generate the root directory root if it doesn't already exist """
-        if not os.path.exists(self.root_dir):
-            os.makedirs(self.root_dir)
-        assert os.path.isdir(self.root_dir), "%s is not a directory! Please move or remove it." % self.root_dir
-        for d in ["bin", "lib"]:
-            target_path = os.path.join(root_dir, d)
-            if not os.path.exists(target_path):
-                os.makedirs(target_path)
-        if not os.path.exists(self.manifest_path):
-            open(self.manifest_path, "w+").close()
-
     def __get_rc_handle(self, root_dir):
         """ get the filepath and filehandle to the rc file for the environment """
         rc_path = os.path.join(root_dir, '.rc')
