@@ -3,12 +3,19 @@ Library module for sprinter. To handle a lot of the typical
 features of the library.
 
 """
+import zipfile
+import gzip
 import inspect
 import imp
+import io
 import os
 import re
+import shutil
 import subprocess
+import tarfile
+import tempfile
 import urllib2
+import urllib
 from StringIO import StringIO
 from base64 import b64encode
 
@@ -37,10 +44,14 @@ def get_formula_class(formula, environment):
     try:
         r = __recursive_import(formula)
         member_dict = dict(inspect.getmembers(r))
+        sprinter_class = FormulaBase
         for v in member_dict.values():
             if inspect.isclass(v) and issubclass(v, FormulaBase) and v != FormulaBase:
-                return v(environment)
-        raise Exception("No formula %s exists in classpath!" % formula)
+                if sprinter_class is FormulaBase:
+                    sprinter_class = v
+        if sprinter_class is None:
+            raise Exception("No formula %s exists in classpath!" % formula)
+        return sprinter_class(environment)
     except ImportError as e:
         raise e
 
@@ -195,6 +206,51 @@ def which(program):
 
     return None
 
+
+def extract_targz(url, target_dir, remove_common_prefix=False):
+    """ extract a targz and install to the target directory """
+    gz = gzip.GzipFile(fileobj=StringIO(urllib2.urlopen(url).read()))
+    tf = tarfile.TarFile(fileobj=gz)
+    if not os.path.exists(target_dir):
+        os.makedirs(target_dir)
+    if not remove_common_prefix:
+        tf.extractall(path=target_dir)
+        return
+    common_prefix = os.path.commonprefix(tf.getnames()) + "/"
+    for tfile in tf.getmembers():
+        tfile.name = tfile.name.replace(common_prefix, "", 1)
+        if tfile.name != "":
+            tf.extract(tfile, target_dir)
+
+
+def extract_zip(url, target_dir, remove_common_prefix=False):
+    if remove_common_prefix:
+        raise("Remove common prefix for zip not implemented yet!")
+    memory_file = io.BytesIO(urllib.urlopen(url).read())
+    zip_file = zipfile.ZipFile(memory_file)
+    zip_file.extractall(target_dir)
+
+
+def extract_dmg(url, target_dir, remove_common_prefix=False):
+    if remove_common_prefix:
+        raise("Remove common prefix for zip not implemented yet!")
+    tmpdir = tempfile.mkdtemp()
+    try:
+        temp_file = os.path.join(tmpdir, "temp.dmg")
+        urllib.urlretrieve(url, temp_file)
+        call("hdiutil attach %s -mountpoint /Volumes/a/" % temp_file)
+        for f in os.listdir("/Volumes/a/"):
+            if not f.startswith(".") and f != ' ':
+                source_path = os.path.join("/Volumes/a", f)
+                target_path = os.path.join(target_dir, f)
+                if os.path.isdir(source_path):
+                    shutil.copytree(source_path, target_path)
+                else:
+                    shutil.copy(source_path, target_path)
+    finally:
+        call("hdiutil unmount /Volumes/a")
+        shutil.rmtree(tmpdir)
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
